==> pyrax-1.4.11.tar.gz: pyrax-1.4.11/samples/cloudfiles/container_cdn.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2012 Rackspace

# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import os
import pyrax

pyrax.set_setting("identity_type", "rackspace")
creds_file = os.path.expanduser("~/.rackspace_cloud_credentials")
pyrax.set_credential_file(creds_file)
cf = pyrax.cloudfiles

cont_name = pyrax.utils.random_name()
cont = cf.create_container(cont_name)
print "Container:", cont
print "Before Making Public"
print "cdn_enabled", cont.cdn_enabled
print "cdn_ttl", cont.cdn_ttl
print "cdn_log_retention", cont.cdn_log_retention
print "cdn_uri", cont.cdn_uri
print "cdn_ssl_uri", cont.cdn_ssl_uri
print "cdn_streaming_uri", cont.cdn_streaming_uri
print "cdn_ios_uri", cont.cdn_ios_uri

# Make it public
cont.make_public(ttl=1200)

# Now re-check the container's attributes
cont = cf.get_container(cont_name)
print
print "After Making Public"
print "cdn_enabled", cont.cdn_enabled
print "cdn_ttl", cont.cdn_ttl
print "cdn_log_retention", cont.cdn_log_retention
print "cdn_uri", cont.cdn_uri
print "cdn_ssl_uri", cont.cdn_ssl_uri
print "cdn_streaming_uri", cont.cdn_streaming_uri
print "cdn_ios_uri", cont.cdn_ios_uri

# clean up
cont.delete()

==> pyrax-1.7.0.tar.gz: pyrax-1.7.0/samples/cloudfiles/container_cdn.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2012 Rackspace

# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from __future__ import print_function

import os
import pyrax

pyrax.set_setting("identity_type", "rackspace")
creds_file = os.path.expanduser("~/.rackspace_cloud_credentials")
pyrax.set_credential_file(creds_file)
cf = pyrax.cloudfiles

cont_name = pyrax.utils.random_name()
cont = cf.create_container(cont_name)
print("Container:", cont)
print("Before Making Public")
print("cdn_enabled", cont.cdn_enabled)
print("cdn_ttl", cont.cdn_ttl)
print("cdn_log_retention", cont.cdn_log_retention)
print("cdn_uri", cont.cdn_uri)
print("cdn_ssl_uri", cont.cdn_ssl_uri)
print("cdn_streaming_uri", cont.cdn_streaming_uri)
print("cdn_ios_uri", cont.cdn_ios_uri
)
# Make it public
cont.make_public(ttl=1200)

# Now re-check the container's attributes
cont = cf.get_container(cont_name)
print()
print("After Making Public")
print("cdn_enabled", cont.cdn_enabled)
print("cdn_ttl", cont.cdn_ttl)
print("cdn_log_retention", cont.cdn_log_retention)
print("cdn_uri", cont.cdn_uri)
print("cdn_ssl_uri", cont.cdn_ssl_uri)
print("cdn_streaming_uri", cont.cdn_streaming_uri)
print("cdn_ios_uri", cont.cdn_ios_uri
)
# clean up
cont.delete()
